==> secretsmanager-1.60.0-sources.jar: software/amazon/awscdk/services/secretsmanager/RotationScheduleOptions.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Options to add a rotation schedule to a secret.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.437Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.RotationScheduleOptions")
@software.amazon.jsii.Jsii.Proxy(RotationScheduleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RotationScheduleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Lambda function that can rotate the secret.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getRotationLambda();

    /**
     * Specifies the number of days after the previous rotation before Secrets Manager triggers the next automatic rotation.
     * <p>
     * Default: Duration.days(30)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getAutomaticallyAfter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link RotationScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RotationScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<RotationScheduleOptions> {
        private software.amazon.awscdk.services.lambda.IFunction rotationLambda;
        private software.amazon.awscdk.core.Duration automaticallyAfter;

        /**
         * Sets the value of {@link RotationScheduleOptions#getRotationLambda}
         * @param rotationLambda The Lambda function that can rotate the secret. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder rotationLambda(software.amazon.awscdk.services.lambda.IFunction rotationLambda) {
            this.rotationLambda = rotationLambda;
            return this;
        }

        /**
         * Sets the value of {@link RotationScheduleOptions#getAutomaticallyAfter}
         * @param automaticallyAfter Specifies the number of days after the previous rotation before Secrets Manager triggers the next automatic rotation.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder automaticallyAfter(software.amazon.awscdk.core.Duration automaticallyAfter) {
            this.automaticallyAfter = automaticallyAfter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RotationScheduleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public RotationScheduleOptions build() {
            return new Jsii$Proxy(rotationLambda, automaticallyAfter);
        }
    }

    /**
     * An implementation for {@link RotationScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RotationScheduleOptions {
        private final software.amazon.awscdk.services.lambda.IFunction rotationLambda;
        private final software.amazon.awscdk.core.Duration automaticallyAfter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.rotationLambda = this.jsiiGet("rotationLambda", software.amazon.awscdk.services.lambda.IFunction.class);
            this.automaticallyAfter = this.jsiiGet("automaticallyAfter", software.amazon.awscdk.core.Duration.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.lambda.IFunction rotationLambda, final software.amazon.awscdk.core.Duration automaticallyAfter) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.rotationLambda = java.util.Objects.requireNonNull(rotationLambda, "rotationLambda is required");
            this.automaticallyAfter = automaticallyAfter;
        }

        @Override
        public software.amazon.awscdk.services.lambda.IFunction getRotationLambda() {
            return this.rotationLambda;
        }

        @Override
        public software.amazon.awscdk.core.Duration getAutomaticallyAfter() {
            return this.automaticallyAfter;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("rotationLambda", om.valueToTree(this.getRotationLambda()));
            if (this.getAutomaticallyAfter() != null) {
                data.set("automaticallyAfter", om.valueToTree(this.getAutomaticallyAfter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.RotationScheduleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RotationScheduleOptions.Jsii$Proxy that = (RotationScheduleOptions.Jsii$Proxy) o;

            if (!rotationLambda.equals(that.rotationLambda)) return false;
            return this.automaticallyAfter != null ? this.automaticallyAfter.equals(that.automaticallyAfter) : that.automaticallyAfter == null;
        }

        @Override
        public int hashCode() {
            int result = this.rotationLambda.hashCode();
            result = 31 * result + (this.automaticallyAfter != null ? this.automaticallyAfter.hashCode() : 0);
            return result;
        }
    }
}

==> secretsmanager-1.100.0-sources.jar: software/amazon/awscdk/services/secretsmanager/RotationScheduleOptions.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Options to add a rotation schedule to a secret.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:15.666Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.RotationScheduleOptions")
@software.amazon.jsii.Jsii.Proxy(RotationScheduleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RotationScheduleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies the number of days after the previous rotation before Secrets Manager triggers the next automatic rotation.
     * <p>
     * Default: Duration.days(30)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getAutomaticallyAfter() {
        return null;
    }

    /**
     * Hosted rotation.
     * <p>
     * Default: - either `rotationLambda` or `hostedRotation` must be specified
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.secretsmanager.HostedRotation getHostedRotation() {
        return null;
    }

    /**
     * A Lambda function that can rotate the secret.
     * <p>
     * Default: - either `rotationLambda` or `hostedRotation` must be specified
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.IFunction getRotationLambda() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link RotationScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RotationScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<RotationScheduleOptions> {
        private software.amazon.awscdk.core.Duration automaticallyAfter;
        private software.amazon.awscdk.services.secretsmanager.HostedRotation hostedRotation;
        private software.amazon.awscdk.services.lambda.IFunction rotationLambda;

        /**
         * Sets the value of {@link RotationScheduleOptions#getAutomaticallyAfter}
         * @param automaticallyAfter Specifies the number of days after the previous rotation before Secrets Manager triggers the next automatic rotation.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder automaticallyAfter(software.amazon.awscdk.core.Duration automaticallyAfter) {
            this.automaticallyAfter = automaticallyAfter;
            return this;
        }

        /**
         * Sets the value of {@link RotationScheduleOptions#getHostedRotation}
         * @param hostedRotation Hosted rotation.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hostedRotation(software.amazon.awscdk.services.secretsmanager.HostedRotation hostedRotation) {
            this.hostedRotation = hostedRotation;
            return this;
        }

        /**
         * Sets the value of {@link RotationScheduleOptions#getRotationLambda}
         * @param rotationLambda A Lambda function that can rotate the secret.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder rotationLambda(software.amazon.awscdk.services.lambda.IFunction rotationLambda) {
            this.rotationLambda = rotationLambda;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RotationScheduleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public RotationScheduleOptions build() {
            return new Jsii$Proxy(automaticallyAfter, hostedRotation, rotationLambda);
        }
    }

    /**
     * An implementation for {@link RotationScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RotationScheduleOptions {
        private final software.amazon.awscdk.core.Duration automaticallyAfter;
        private final software.amazon.awscdk.services.secretsmanager.HostedRotation hostedRotation;
        private final software.amazon.awscdk.services.lambda.IFunction rotationLambda;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.automaticallyAfter = software.amazon.jsii.Kernel.get(this, "automaticallyAfter", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
            this.hostedRotation = software.amazon.jsii.Kernel.get(this, "hostedRotation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotation.class));
            this.rotationLambda = software.amazon.jsii.Kernel.get(this, "rotationLambda", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.core.Duration automaticallyAfter, final software.amazon.awscdk.services.secretsmanager.HostedRotation hostedRotation, final software.amazon.awscdk.services.lambda.IFunction rotationLambda) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.automaticallyAfter = automaticallyAfter;
            this.hostedRotation = hostedRotation;
            this.rotationLambda = rotationLambda;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getAutomaticallyAfter() {
            return this.automaticallyAfter;
        }

        @Override
        public final software.amazon.awscdk.services.secretsmanager.HostedRotation getHostedRotation() {
            return this.hostedRotation;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.IFunction getRotationLambda() {
            return this.rotationLambda;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAutomaticallyAfter() != null) {
                data.set("automaticallyAfter", om.valueToTree(this.getAutomaticallyAfter()));
            }
            if (this.getHostedRotation() != null) {
                data.set("hostedRotation", om.valueToTree(this.getHostedRotation()));
            }
            if (this.getRotationLambda() != null) {
                data.set("rotationLambda", om.valueToTree(this.getRotationLambda()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.RotationScheduleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RotationScheduleOptions.Jsii$Proxy that = (RotationScheduleOptions.Jsii$Proxy) o;

            if (this.automaticallyAfter != null ? !this.automaticallyAfter.equals(that.automaticallyAfter) : that.automaticallyAfter != null) return false;
            if (this.hostedRotation != null ? !this.hostedRotation.equals(that.hostedRotation) : that.hostedRotation != null) return false;
            return this.rotationLambda != null ? this.rotationLambda.equals(that.rotationLambda) : that.rotationLambda == null;
        }

        @Override
        public final int hashCode() {
            int result = this.automaticallyAfter != null ? this.automaticallyAfter.hashCode() : 0;
            result = 31 * result + (this.hostedRotation != null ? this.hostedRotation.hashCode() : 0);
            result = 31 * result + (this.rotationLambda != null ? this.rotationLambda.hashCode() : 0);
            return result;
        }
    }
}
